==> haskell-mmap-0.5.9-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-1vohpNI5UyxERqLmyV34PM
key:                  mmap-0.5.9-1vohpNI5UyxERqLmyV34PM
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  ed2d721d96db52d161e2375a47837dd4
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-8.10.2/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/mmap-0.5.9
hs-libraries:         HSmmap-0.5.9-1vohpNI5UyxERqLmyV34PM
depends:              base-4.14.1.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmap-0.5.9-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-AeMhBFCLycRGGScmgorM0n
key:                  mmap-0.5.9-AeMhBFCLycRGGScmgorM0n
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  e3f809bb3f5dcf021966ad93aee9748d
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-8.10.3/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/mmap-0.5.9
hs-libraries:         HSmmap-0.5.9-AeMhBFCLycRGGScmgorM0n
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
